def get_classes():

    from Input import Input
    return [Input]


messages = [
    "INPUT_ACT_REPORT_CONTEXT",

    "INPUT_EV_CONTEXT_MENU",
    "INPUT_EV_CONTEXT_PLAYER",
    "INPUT_EV_CONTEXT_BROWSER",
    "INPUT_EV_CONTEXT_FULLSCREEN",

    #
    # The custom contexts must not be used by the application. They're meant
    # for internal use by the input schemas only in order to allow for a more
    # finegrained navigation.
    #
    "INPUT_EV_CONTEXT_CUSTOM_0",
    "INPUT_EV_CONTEXT_CUSTOM_1",
    "INPUT_EV_CONTEXT_CUSTOM_2",
    "INPUT_EV_CONTEXT_CUSTOM_3",
    "INPUT_EV_CONTEXT_CUSTOM_4",
    "INPUT_EV_CONTEXT_CUSTOM_5",
    "INPUT_EV_CONTEXT_CUSTOM_6",
    "INPUT_EV_CONTEXT_CUSTOM_7",
    "INPUT_EV_CONTEXT_CUSTOM_8",
    "INPUT_EV_CONTEXT_CUSTOM_9",
    "INPUT_EV_CONTEXT_CUSTOM_10",
    "INPUT_EV_CONTEXT_CUSTOM_11",
    "INPUT_EV_CONTEXT_CUSTOM_12",
    "INPUT_EV_CONTEXT_CUSTOM_13",
    "INPUT_EV_CONTEXT_CUSTOM_14",
    "INPUT_EV_CONTEXT_CUSTOM_15",
    


    "INPUT_EV_VOLUME_UP",
    "INPUT_EV_VOLUME_DOWN",
    "INPUT_EV_PREVIOUS",
    "INPUT_EV_NEXT",
    "INPUT_EV_REWIND",
    "INPUT_EV_FORWARD",
    "INPUT_EV_PLAY",
    "INPUT_EV_MENU",
    "INPUT_EV_ENTER",
    "INPUT_EV_FULLSCREEN",
    "INPUT_EV_EJECT",

    "INPUT_EV_PREVIOUS_VIEWER",
    "INPUT_EV_NEXT_VIEWER",

    "INPUT_EV_UP",
    "INPUT_EV_DOWN",
    "INPUT_EV_LEFT",
    "INPUT_EV_RIGHT",

    # DVD navigation, etc.
    "INPUT_EV_NAV_UP",
    "INPUT_EV_NAV_DOWN",
    "INPUT_EV_NAV_LEFT",
    "INPUT_EV_NAV_RIGHT",
    "INPUT_EV_NAV_ENTER",
    "INPUT_EV_NAV_MENU",
]
